@@ -1,5 +1,5 @@
 /* pinentry.h - The interface for the PIN entry support library.
-   Copyright (C) 2002, 2003 g10 Code GmbH
+   Copyright (C) 2002, 2003, 2010 g10 Code GmbH
    
    This file is part of PINENTRY.
    
@@ -14,9 +14,8 @@
    General Public License for more details.
  
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA  */
+   along with this program; if not, see <http://www.gnu.org/licenses/>. 
+ */
 
 #ifndef PINENTRY_H
 #define PINENTRY_H
@@ -28,6 +27,8 @@ extern "C" {
 #endif
 #endif
 
+#undef ENABLE_ENHANCED
+
 typedef enum {
   PINENTRY_COLOR_NONE, PINENTRY_COLOR_DEFAULT,
   PINENTRY_COLOR_BLACK, PINENTRY_COLOR_RED,
@@ -70,8 +71,15 @@ struct pinentry
 
   /* True if debug mode is requested.  */
   int debug;
+
+  /* The number of seconds before giving up while waiting for user input. */
+  int timeout;
+
+#ifdef ENABLE_ENHANCED
   /* True if enhanced mode is requested.  */
   int enhanced;
+#endif
+
   /* True if caller should grab the keyboard.  */
   int grab;
   /* The window ID of the parent window over which the pinentry window
@@ -93,6 +101,11 @@ struct pinentry
      conversion occured. */
   int locale_err;
 
+  /* The user should set this to true if the window close button has
+     been used.  This flag is used in addition to a regular return
+     value.  */
+  int close_button;
+
   /* The caller should set this to true if only one button is
      required.  This is useful for notification dialogs where only a
      dismiss button is required. */
@@ -101,7 +114,7 @@ struct pinentry
   /* If this is not NULL, a passphrase quality indicator is shown.
      There will also be an inquiry back to the caller to get an
      indication of the quality for the passphrase entered so far.  The
-     string is used as a labe for the auality bar.  */
+     string is used as a label for the quality bar.  */
   char *quality_bar;
 
   /* The tooltip to be show for the qualitybar.  Malloced or NULL.  */
@@ -114,9 +127,17 @@ struct pinentry
   pinentry_color_t color_so;
   int color_so_bright;
 
-  /* Fo the quality indicator we need to do an inquiry.  Thus we need
+  /* Malloced and i18ned default strings or NULL.  These strings may
+     include an underscore character to indicate an accelerator key.
+     A double underscore represents a plain one.  */
+  char *default_ok;
+  char *default_cancel;
+  char *default_prompt;
+
+  /* For the quality indicator we need to do an inquiry.  Thus we need
      to save the assuan ctx.  */
   void *ctx_assuan;
+
 };
 typedef struct pinentry *pinentry_t;
 
@@ -134,6 +155,9 @@ typedef int (*pinentry_cmd_handler_t) (pinentry_t pin);
    error.  Otherwise, 0 is returned.  */
 int pinentry_loop (void);
 
+/* The same as above but allows to specify the i/o descriptors. */
+int pinentry_loop2 (int infd, int outfd);
+
 
 /* Convert the UTF-8 encoded string TEXT to the encoding given in
    LC_CTYPE.  Return NULL on error. */
